@@ -26,7 +26,7 @@
     You should have received a copy of the GNU General Public License
     along with PSPManalysis. If not, see <http://www.gnu.org/licenses/>.
 
-    Last modification: AMdR - Dec 06, 2021
+    Last modification: AMdR - Apr 08, 2022
 ***/
 
 #define PSPMIND                   1
@@ -410,7 +410,7 @@ void InitialiseVars(void)
 #endif
 
   // Get the machine precisions
-  epsMach = dlamch("Epsilon");
+  epsMach = dlamch("Epsilon" FCONE);
 
   CurPopulationNr   = PopulationNr;
   CohortDim         = IStateDim + 1 + InteractDim;
